####################################################################
#                                                                  #
#     The network structure of schizotypal personality traits      #
#        Schizophrenia Bulletin 2018, Fonseca-Pedrero et al.       #
#                                                                  #    
#                Codes by Eiko Fried, eiko-fried.com               #
#                  Last update: February 26th 2018                 #
#                                                                  #    
####################################################################



# ---------- Table of Contents ----------------------------------------------------------
# ---------- 1. Load Libraries ----------------------------------------------------------
# ---------- 2. Data preparation --------------------------------------------------------
# ---------- 3. Descriptives & objects --------------------------------------------------
# ---------- 4. Small network, full sample ----------------------------------------------
# ---------- 5. Large network, full sample ----------------------------------------------
# ---------- 6. Networks gender ---------------------------------------------------------
# ---------- 7. Networks North America vs China -----------------------------------------
# ---------- 8. Stability ---------------------------------------------------------------



# ---------------------------------------------------------------------------------------
# ---------- 1. Load libraries ----------------------------------------------------------
# ---------------------------------------------------------------------------------------

library('qgraph')
library('IsingFit')
library('bootnet')
library('dplyr')
library('reshape2')
library('foreign')
library('mgm')
library('Hmisc')
library('devtools')
install_github("sachaepskamp/bootnet")
install_github("sachaepskamp/qgraph")



# ---------------------------------------------------------------------------------------
# ---------- 2. Data preparation --------------------------------------------------------
# ---------------------------------------------------------------------------------------

data<-read.spss("SPQ_network.sav", to.data.frame = TRUE)

data[,7:80] <- sapply(data[,7:80], as.numeric)
data[,7:80][is.na(data)[,7:80]] <- 0

data1 <- data[,7:80] # only symptoms
data_m <- filter(data[,c(3,7:80)], Gender=="Male")
data_m <- data_m[,-1]
data_f <- filter(data[,c(3,7:80)], Gender=="Female")
data_f <- data_f[,-1]

data_west <- filter(data[,c(2,7:80)], country=="EEUU" | country=="canada")
                       # country=="Spain" | country=="New zealand" |
                       #   country=="italy" | country=="australia" | country=="belgium" |
                       #   country=="Uk" | country=="canada" | country=="greek")
data_west <- data_west[,-1]
data_east <- filter(data[,c(2,7:80)], country=="china")
data_east <- data_east[,-1]



# ---------------------------------------------------------------------------------------
# ---------- 3. Descriptives & objects --------------------------------------------------
# ---------------------------------------------------------------------------------------

load(file="SavedObjects.RData")
save(gr, diff_means1, means_m, means_f, 
      graph1, EI_m, EI_f, EI_gender, EI0, 
      graph_east, graph_west, 
      EI_west, EI_east, EI_country, means_west, means_east, diff_means2, scale_pred, 
      names, longnames, fitobj_small, graph_small, 
      EI_small, 
      file="SavedObjects.RData")

### gender
rowsum_m <- rowSums(data_m)
rowsum_f <- rowSums(data_f)
t.test(rowsum_m, rowsum_f) 
# t = 2.3982, df = 21333, p-value = 0.01648
# mean of x mean of y 
# 21.47659  21.09531 

### eastern vs western 
# EEUU       Spain    New zealand  italy   australia   belgium    Uk     tunisia 
# 10477      1123     1698         649     1931        893        774    458 
# china      canada   greek        mauritius 
# 4907       1849     1041        1201 
rowsum_west <- rowSums(data_west)
rowsum_east <- rowSums(data_east)
t.test(rowsum_west, rowsum_east) 
# t = -1.156, df = 11965, p-value = 0.2477
# mean of x mean of y 
# 21.13674  21.35810 

### general means and sds
means <- as.vector(sapply(data1, mean))
sds <- as.vector(sapply(data1, sd))
layout(t(1:2))
hist(means)
hist(sds)
dev.off()



# ---------------------------------------------------------------------------------------
# ---------- 4. Small network, full sample ----------------------------------------------
# ---------------------------------------------------------------------------------------

### full data
# estimate
colnames(data1) <- colnames(data_m) <- colnames(data_f) <- colnames(data_east) <- colnames(data_west) <- c(1:74)
gr <- list("Ideas of reference"=c(1,10,19,28,37,45,53,60,63), 
           "Excessive social anxiety"=c(2,11,20,29,38,46,54,71), 
           "Odd beliefs or magical thinking"=c(3,12,21,30,39,47, 55), 
           "Unusual perceptual experiences"=c(4, 13, 22, 31, 40, 48, 56, 61, 64), 
           "Odd or eccentric behavior"=c(5, 14, 23, 32, 67, 70, 74), 
           "No close friends"=c(6, 15, 24, 33,41, 49, 57, 62, 66),
           "Odd speech"=c(7, 16, 25, 34, 42, 50, 58, 69, 72),
           "Constricted affect"=c(8, 17, 26, 35, 43, 51, 68, 73),
           "Suspiciousness"=c(9, 18, 27, 36, 44, 52, 59, 65))          

longnames <- c("Ideas of reference", "Social anxiety", "Odd/magical beliefs",
           "Unusual perceptions", "Odd/eccentric behavior", "No close friends", 
           "Odd speech", "Constricted affect", "Suspiciousness")      
names <- c("D1","D2","D3","D4","D5","D6","D7","D8","D9")

### small network
data_small <- data1
data_small$D1 <- scale(rowSums(data1[,c(1,10,19,28,37,45,53,60,63)]))
data_small$D2 <- scale(rowSums(data1[,c(2,11,20,29,38,46,54,71)]))
data_small$D3 <- scale(rowSums(data1[,c(3,12,21,30,39,47, 55)]))
data_small$D4 <- scale(rowSums(data1[,c(4, 13, 22, 31, 40, 48, 56, 61, 64)]))
data_small$D5 <- scale(rowSums(data1[,c(5, 14, 23, 32, 67, 70, 74)]))
data_small$D6 <- scale(rowSums(data1[,c(6, 15, 24, 33,41, 49, 57, 62, 66)]))
data_small$D7 <- scale(rowSums(data1[,c(7, 16, 25, 34, 42, 50, 58, 69, 72)]))
data_small$D8 <- scale(rowSums(data1[,c(8, 17, 26, 35, 43, 51, 68, 73)]))
data_small$D9 <- scale(rowSums(data1[,c(9, 18, 27, 36, 44, 52, 59, 65)]))    

# predictability small network
fitobj_small <- mgm(data_small[,c(75:83)], type=rep('g', 9) , lev=rep(1,9)) 
predobj_small <- predict(fitobj_small, data_small[,c(75:83)], error.Con='R2') 
mean(predobj_small$error$R2) # 43.7%

# plot
smallNetwork <- estimateNetwork(data_small[,c(75:83)], default="EBICglasso", lambda.min.ratio=0.001) # lambda warning, so we set it lower to 0.001
graph_small <- plot(smallNetwork, layout = "spring", pie=predobj_small$error$R2, cut=0, vsize=7, 
                    filename="Network_small", width=6, height=5, repulsion=1.1, 
                    border.color='#555555', label.color="#555555", labels=names,
                    nodeNames = longnames, filetype="pdf", theme='colorblind')

smallNetwork$graph

# EI (expected influence)
EI_small <- scale(colSums(smallNetwork$graph)) 
pdf("EI_small.pdf", width=6, height=4)
plot(EI_small, xlab="SPQ domains", ylab="Expected Influence", xlim=c(1,9), ylim=c(-3,3))
abline(h=0,col="black", lty = 3)
abline(h=c(-3,-2,-1,1,2,3), col="#d6d6d6")
axis(1,at=c(1,3,5,7,9))
lines(EI_small, type="l", col="#555555")
lines(EI_small, type="b", col="#555555", pch=21, bg="#555555")
# lines(predobj_small$error$R2*10-4, type="b", col='red')        # this is predictability; not added in paper
dev.off()

# correlation EI and predictability
cor(EI_small, predobj_small$error$R2) #0.8532475



# ---------------------------------------------------------------------------------------
# ---------- 5. Large network, full sample ----------------------------------------------
# ---------------------------------------------------------------------------------------

network1 <- estimateNetwork(data1, default="IsingFit")

# predictability
fitobj <- mgm(data1, type=rep('c', 74), lev=rep(2,74)) 
predobj <- predict(fitobj, data1, errorCat=c('CC', 'nCC', 'CCmarg')) 
mean(predobj$error$nCC) #27.8

# predictability per subscale
scale_pred <- list(mean(predobj$error$nCC[c(1,10,19,28,37,45,53,60,63)]),
                      mean(predobj$error$nCC[c(2,11,20,29,38,46,54,71)]),
                      mean(predobj$error$nCC[c(3,12,21,30,39,47, 55)]),
                      mean(predobj$error$nCC[c(4, 13, 22, 31, 40, 48, 56, 61, 64)]),
                      mean(predobj$error$nCC[c(5, 14, 23, 32, 67, 70, 74)]),
                      mean(predobj$error$nCC[c(6, 15, 24, 33,41, 49, 57, 62, 66)]),
                      mean(predobj$error$nCC[c(7, 16, 25, 34, 42, 50, 58, 69, 72)]),
                      mean(predobj$error$nCC[c(8, 17, 26, 35, 43, 51, 68, 73)]),
                      mean(predobj$error$nCC[c(9, 18, 27, 36, 44, 52, 59, 65)]));scale_pred

# plot
graph1 <- plot(network1, layout = "spring", pie=predobj$error$Error, cut=0, usePCH = FALSE,
     filetype="pdf", filename="Network_full", theme='colorblind',
     groups=gr, palette="pastel", vsize=4,
     border.color='#555555', label.color="#555555")

### centrality (expected influence)
EI <- scale(colSums(network1$graph)) 
EI0 <- matrix(nrow=74, ncol=2); EI0[,1] <- c(1:74); EI0[,2] <- rep(17, 74) # to avoid plotting problems with overlay

pdf("EI_full.pdf", width=10, height=5)
plot(EI0, xlab="SPQ items", ylab="Expected Influence", xlim=c(1,74), ylim=c(-3,3))
abline(h=0,col="black", lty = 3)
abline(h=c(-3,-2,-1,1,2,3), col="#d6d6d6")
abline(v=c(0, 5,10,15,20, 25,30,35,40, 45,50,55,60, 65,70, 75), col="#d6d6d6")
axis(1,at=c(5,10,15,25,30,35,45,50,55,65,70,75))
minor.tick(nx=20, tick.ratio=.4)
lines(EI, type="l", col="#555555")
lines(EI, type="b", col="#555555", cex=.7, pch=21, bg="#555555")
dev.off()

# correlation EI and predictability
cor(EI, predobj$error$nCC) #.38
max(predobj$error$nCC) #.59 node 38
min(predobj$error$nCC) #.03 node 22

# investigate connectivity within and between 9 subscales
d1 <- network1$graph[c(1,10,19,28,37,45,53,60,63),c(1,10,19,28,37,45,53,60,63)]                     
d1b <- network1$graph[c(1,10,19,28,37,45,53,60,63),-c(1,10,19,28,37,45,53,60,63)]                     
d2 <- network1$graph[c(2,11,20,29,38,46,54,71),c(2,11,20,29,38,46,54,71)]
d2b <- network1$graph[c(2,11,20,29,38,46,54,71),-c(2,11,20,29,38,46,54,71)]
d3 <- network1$graph[c(3,12,21,30,39,47, 55),c(3,12,21,30,39,47, 55)]
d3b <- network1$graph[c(3,12,21,30,39,47, 55),-c(3,12,21,30,39,47, 55)]
d4 <- network1$graph[c(4, 13, 22, 31, 40, 48, 56, 61, 64),c(4, 13, 22, 31, 40, 48, 56, 61, 64)]
d4b <- network1$graph[c(4, 13, 22, 31, 40, 48, 56, 61, 64),-c(4, 13, 22, 31, 40, 48, 56, 61, 64)]
d5 <- network1$graph[c(5, 14, 23, 32, 67, 70, 74),c(5, 14, 23, 32, 67, 70, 74)]
d5b <- network1$graph[c(5, 14, 23, 32, 67, 70, 74),-c(5, 14, 23, 32, 67, 70, 74)]
d6 <- network1$graph[c(6, 15, 24, 33,41, 49, 57, 62, 66),c(6, 15, 24, 33,41, 49, 57, 62, 66)]
d6b <- network1$graph[c(6, 15, 24, 33,41, 49, 57, 62, 66),-c(6, 15, 24, 33,41, 49, 57, 62, 66)]
d7 <- network1$graph[c(7, 16, 25, 34, 42, 50, 58, 69, 72),c(7, 16, 25, 34, 42, 50, 58, 69, 72)]
d7b <- network1$graph[c(7, 16, 25, 34, 42, 50, 58, 69, 72),-c(7, 16, 25, 34, 42, 50, 58, 69, 72)]
d8 <- network1$graph[c(8, 17, 26, 35, 43, 51, 68, 73),c(8, 17, 26, 35, 43, 51, 68, 73)]
d8b <- network1$graph[c(8, 17, 26, 35, 43, 51, 68, 73),-c(8, 17, 26, 35, 43, 51, 68, 73)]
d9 <- network1$graph[c(9, 18, 27, 36, 44, 52, 59, 65),c(9, 18, 27, 36, 44, 52, 59, 65)]
d9b <- network1$graph[c(9, 18, 27, 36, 44, 52, 59, 65),-c(9, 18, 27, 36, 44, 52, 59, 65)]

MeanWeightsWithin <- c(mean(abs(d1[upper.tri(d1)])),  #.33
                 mean(abs(d2[upper.tri(d2)])),        #.45
                 mean(abs(d3[upper.tri(d3)])),        #.47 
                 mean(abs(d4[upper.tri(d4)])),        #.26
                 mean(abs(d5[upper.tri(d5)])),        #.61 
                 mean(abs(d6[upper.tri(d6)])),        #.31
                 mean(abs(d7[upper.tri(d7)])),        #.37
                 mean(abs(d8[upper.tri(d8)])),        #.24
                 mean(abs(d9[upper.tri(d9)])))        #.44
mean(MeanWeightsWithin) # .39

MeanWeightsBetween <- c(mean(abs(d1b)),               #.07
                        mean(abs(d2b)),               #.05
                        mean(abs(d3b)),               #.06
                        mean(abs(d4b)),               #.05
                        mean(abs(d5b)),               #.04
                        mean(abs(d6b)),               #.06
                        mean(abs(d7b)),               #.06
                        mean(abs(d8b)),               #.07
                        mean(abs(d9b)))               #.05 
mean(MeanWeightsBetween) # .05

mean(abs(network1$graph[upper.tri(network1$graph)])) #.09

# investigate connectivity within and between 3 higher-order dimensions
positive <- c(1,10,19,28,37,45,53,60,63, 3,12,21,30,39,47, 55, 4, 13, 22, 31, 40, 48, 56, 61, 64, 9, 18, 27, 36, 44, 52, 59, 65)
interpersonal <- c(2,11,20,29,38,46,54,71, 6, 15, 24, 33,41, 49, 57, 62, 66,8, 17, 26, 35, 43, 51, 68, 73,9, 18, 27, 36, 44, 52, 59, 65)
disorganization <- c(5, 14, 23, 32, 67, 70, 74, 7, 16, 25, 34, 42, 50, 58, 69, 72)

h1 <- network1$graph[positive,positive]                     
h1b <- network1$graph[positive,-positive]                     
h2 <- network1$graph[interpersonal,interpersonal]                     
h2b <- network1$graph[interpersonal,-interpersonal]
h3 <- network1$graph[disorganization,disorganization]                     
h3b <- network1$graph[disorganization,-disorganization]

MeanWeightsWithin2 <- c(mean(abs(h1[upper.tri(h1)])),       #.15
                       mean(abs(h2[upper.tri(h2)])),        #.15
                       mean(abs(h3[upper.tri(h3)])))        #.27

mean(MeanWeightsWithin2) #.19

MeanWeightsBetween2 <- c(mean(abs(h1b)),                    #.04
                        mean(abs(h2b)),                     #.04
                        mean(abs(h3b)))                     #.04
mean(MeanWeightsBetween2) # .04



# ---------------------------------------------------------------------------------------
# ---------- 6. Networks gender ---------------------------------------------------------
# ---------------------------------------------------------------------------------------

### estimate male network
network_m <- estimateNetwork(data_m, default="IsingFit")
graph_m <- plot(network_m, layout=graph1$layout, cut=0, vsize=4, 
                filetype="pdf", filename="network_m", maximum=2.61, groups=gr, 
                palette="pastel", theme='colorblind') #2.31

sum(abs(network_m$graph))/2 # 195.59

network_f_FULL <- estimateNetwork(data_f, default="IsingFit") # we only use this for bootnet() routines

### estimate female network: subsample to obtain comparable samples
set.seed(1); data_f1 <- sample_n(data_f, 10126, replace=TRUE); network_f1 <- estimateNetwork(data_f1, default="IsingFit")
set.seed(2); data_f2 <- sample_n(data_f, 10126, replace=TRUE); network_f2 <- estimateNetwork(data_f2, default="IsingFit")
set.seed(3); data_f3 <- sample_n(data_f, 10126, replace=TRUE); network_f3 <- estimateNetwork(data_f3, default="IsingFit")
set.seed(4); data_f4 <- sample_n(data_f, 10126, replace=TRUE); network_f4 <- estimateNetwork(data_f4, default="IsingFit")
set.seed(5); data_f5 <- sample_n(data_f, 10126, replace=TRUE); network_f5 <- estimateNetwork(data_f5, default="IsingFit")
set.seed(6); data_f6 <- sample_n(data_f, 10126, replace=TRUE); network_f6 <- estimateNetwork(data_f6, default="IsingFit")
set.seed(7); data_f7 <- sample_n(data_f, 10126, replace=TRUE); network_f7 <- estimateNetwork(data_f7, default="IsingFit")
set.seed(8); data_f8 <- sample_n(data_f, 10126, replace=TRUE); network_f8 <- estimateNetwork(data_f8, default="IsingFit")
set.seed(9); data_f9 <- sample_n(data_f, 10126, replace=TRUE); network_f9 <- estimateNetwork(data_f9, default="IsingFit")
set.seed(10); data_f10 <- sample_n(data_f, 10126, replace=TRUE); network_f10 <- estimateNetwork(data_f10, default="IsingFit")

network_f <- (network_f1$graph + 
          network_f2$graph + 
          network_f3$graph + 
          network_f4$graph + 
          network_f5$graph + 
          network_f6$graph + 
          network_f7$graph + 
          network_f8$graph + 
          network_f9$graph + 
          network_f10$graph) /10

sum(abs(network_f))/2 # 199.70 (nearly identical to male network with 195.59)

graph_f <- qgraph(network_f, layout=graph1$layout, cut=0, labels=c(1:74), vsize=4,
                filetype="pdf", filename="network_f", groups=gr, palette="pastel",
                theme='colorblind') #2.61

cor(network_f [lower.tri(network_f )], network_m$graph[lower.tri(network_m$graph)], method="spearman")   #0.74

### centrality (expected influence)
EI_m<-scale(colSums(network_m$graph))
EI_f<-scale(colSums(network_f))
EI_gender <- EI_m-EI_f
cor(EI_m, EI_f) # .90

### mean symptom comparison
means_m <- as.vector(sapply(data_m, mean))
means_f <- as.vector(sapply(data_f, mean))
diff_means1 <- means_m - means_f      
cor(means_m, means_f) #0.91

sum(abs(diff_means1)) # 3.30
# sum(abs(diff_means2)) # 10.28

max(abs(diff_means1))

# ---------------------------------------------------------------------------------------
# ---------- 7. Networks North America vs China -----------------------------------------
# ---------------------------------------------------------------------------------------

### network estimation East
network_east <- estimateNetwork(data_east, default="IsingFit")
graph_east <- plot(network_east, layout=graph1$layout, cut=0, vsize=4, groups=gr, palette="pastel",
                   filetype="pdf", filename="network_east", maximum=2.82, labels=c(1:74),
                   theme='colorblind') # max=2.33

sum(abs(network_east$graph))/2 # 153.97

### network estimation West with subsetting
set.seed(1); data_west1 <- sample_n(data_west, 4907, replace=TRUE); network_west1 <- estimateNetwork(data_west1, default="IsingFit")
set.seed(2); data_west2 <- sample_n(data_west, 4907, replace=TRUE); network_west2 <- estimateNetwork(data_west2, default="IsingFit")
set.seed(3); data_west3 <- sample_n(data_west, 4907, replace=TRUE); network_west3 <- estimateNetwork(data_west3, default="IsingFit")
set.seed(4); data_west4 <- sample_n(data_west, 4907, replace=TRUE); network_west4 <- estimateNetwork(data_west4, default="IsingFit")
set.seed(5); data_west5 <- sample_n(data_west, 4907, replace=TRUE); network_west5 <- estimateNetwork(data_west5, default="IsingFit")
set.seed(6); data_west6 <- sample_n(data_west, 4907, replace=TRUE); network_west6 <- estimateNetwork(data_west6, default="IsingFit")
set.seed(7); data_west7 <- sample_n(data_west, 4907, replace=TRUE); network_west7 <- estimateNetwork(data_west7, default="IsingFit")
set.seed(8); data_west8 <- sample_n(data_west, 4907, replace=TRUE); network_west8 <- estimateNetwork(data_west8, default="IsingFit")
set.seed(9); data_west9 <- sample_n(data_west, 4907, replace=TRUE); network_west9 <- estimateNetwork(data_west9, default="IsingFit")
set.seed(10); data_west10 <- sample_n(data_west, 4907, replace=TRUE); network_west10 <- estimateNetwork(data_west10, default="IsingFit")

network_west <- (network_west1$graph +
                network_west2$graph +
                network_west3$graph +
                network_west4$graph +
                network_west5$graph +
                network_west6$graph +
                network_west7$graph +
                network_west8$graph +
                network_west9$graph +
                network_west10$graph) /10

sum(abs(network_west))/2 # 180.35; substantially denser than 153.97 East

graph_west <- qgraph(network_west, layout=graph1$layout, cut=0, labels=c(1:74),
                     vsize=4,  groups=gr, palette="pastel",
                     filetype="pdf", filename="network_west",
                     theme='colorblind') #2.82

cor(network_west [lower.tri(network_west )], network_east$graph[lower.tri(network_east$graph)], method="spearman")   #0.44


### centrality
EI_west <- scale(colSums(network_west))
EI_east <- scale(colSums(network_east$graph))
cor(EI_west,EI_east) # 0.56

EI_country <- EI_west-EI_east

pdf("EI_differences.pdf", width=10, height=5)
plot(EI0, xlab="SPQ items", ylab="Expected Influence differences", xlim=c(1,74), ylim=c(-3,3))
abline(h=0,col="black", lty = 3)
axis(1,at=c(5,10,15,25,30,35,45,50,55,65,70,75))
minor.tick(nx=20, tick.ratio=.4)
abline(h=c(-3,-2,-1,1,2,3), col="#d6d6d6")
abline(v=c(0, 5,10,15,20, 25,30,35,40, 45,50,55,60, 65,70, 75), col="#d6d6d6")
lines(EI_gender, type="l", col="#bbbbbb")
lines(EI_gender, type="b", col="#bbbbbb", cex=.7, pch=21, bg="#bbbbbb")
lines(EI_country, type="l", col="black")
lines(EI_country, type="b", col="black", cex=.7, pch=21, bg="black")
legend(0,2.8, legend=c("Difference Men - Women", "Difference West - East"), lty=c(1,1), lwd=c(2,2), col=c("#bbbbbb","black"), bg="white")
dev.off()

### mean symptom comparison
means_west <- as.vector(sapply(data_west, mean))
means_east <- as.vector(sapply(data_east, mean))
diff_means2 <- means_west - means_east

sum(abs(diff_means1)) # 3.30
sum(abs(diff_means2)) # 10.28

pdf("mean_differences.pdf", width=10, height=5)
plot(EI0, xlab="SPQ items", ylab="Mean differences", xlim=c(1,74), ylim=c(-.5,.5))
abline(h=0,col="black", lty = 3)
axis(1,at=c(5,10,15,25,30,35,45,50,55,65,70,75))
minor.tick(nx=20, tick.ratio=.4)
abline(h=c(-.4,-.2,.2,.4), col="#d6d6d6")
abline(v=c(0, 5,10,15,20, 25,30,35,40, 45,50,55,60, 65,70, 75), col="#d6d6d6")
lines(diff_means1, type="l", col="#bbbbbb")
lines(diff_means1, type="b", col="#bbbbbb", cex=.7, pch=21, bg="#bbbbbb")
lines(diff_means2, type="l", col="black")
lines(diff_means2, type="b", col="black", cex=.7, pch=21, bg="black")
legend(54,-.29, legend=c("Difference Men/Women", "Difference West/East"), lty=c(1,1), lwd=c(2,2), col=c("#bbbbbb","black"), bg="white")
dev.off()



# ---------------------------------------------------------------------------------------
# ---------- 8. Stability ---------------------------------------------------------------
# ---------------------------------------------------------------------------------------

# we performed the stability analysis as described in Epskamp, S., Borsboom, D., & Fried, E. I. (2017). Estimating Psychological Networks and their Accuracy: A Tutorial Paper. Behavior Research Methods, 1–34. http://doi.org/10.3758/s13428-017-0862-1
# codes used for the estimation on the local Amsterdam computing cluster for the 74-node networks are available on request
# codes used for the bootstrapping routines of the small domain network are presented below

### bootstrapping
b1 <- bootnet(smallNetwork, nBoots=1000, nCores=8, 
              statistics=c("strength","expectedInfluence","closeness","betweenness"))

b2 <- bootnet(smallNetwork, nBoots=1000, nCores=8, type="case",
              statistics=c("strength","expectedInfluence","closeness","betweenness"))

### Plot edge weight CI
pdf("FigS1.pdf")
plot(b1, labels = TRUE, order = "sample") 
dev.off()

### Edge weights diff test
pdf("FigS2.pdf")
plot(b1, "edge", plot = "difference", onlyNonZero = TRUE, order = "sample")
dev.off()

### Plot centrality stability
pdf("FigS3.pdf") 
plot(b2, statistics=c("expectedInfluence"))
dev.off()

### Centrality stability coefficient
corStability(b2, statistic="expectedInfluence")

### Centrality diff test
pdf("FigS4.pdf")
plot(b1, "expectedInfluence", order="sample", labels=TRUE) 
dev.off()
